//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from "react";
import Button from "../../controls/action-button";
import { COLORS, isNonEmptyString, libTrackIsOn } from "primeobjects-helper-util";
import { SVG } from "primeobjects-ui-web-basic";
import { getAIExtractorFileName, startAIExtractorJob } from "./ai-extractor-util";
export var AIExtractorFormForUser = function (props) {
    var entity = props.entity, hideTabs = props.hideTabs, onGoBack = props.onGoBack, record = props.record;
    var FormWrapper = props.FormWrapper;
    var getGeneralForm = function (customProps) {
        var solution = customProps.solution, isError = customProps.isError, isDoing = customProps.isDoing, version = customProps.version, disabled = customProps.disabled, onStartAPICall = customProps.onStartAPICall, onSuccessAPICall = customProps.onSuccessAPICall, toChangeRecord = customProps.toChangeRecord, onErrorAPICall = customProps.onErrorAPICall, onError = customProps.onError;
        var getRows = function (record) {
            if (libTrackIsOn())
                console.log({ record: record });
            var updateRecord = function (newRecord) {
                record = newRecord;
                toChangeRecord(record);
            };
            var clearAllError = function () {
                onError("ai", false);
            };
            var onClickSubmitButton = function () {
                startAIExtractorJob(solution, record, "task", updateRecord, onStartAPICall, onSuccessAPICall, onErrorAPICall);
            };
            return [
                (isNonEmptyString(record.name) ||
                    isNonEmptyString(record.description)) && {
                    fields: [
                        {
                            name: "introduction",
                            type: "container",
                            content: (React.createElement("div", { className: "w-full" },
                                isNonEmptyString(record.name) && (React.createElement("div", { className: "font-medium text-base mb-1" }, record.name)),
                                isNonEmptyString(record.description) && (React.createElement("div", { className: "text-sm" }, record.description))))
                        }
                    ]
                },
                {
                    fields: [
                        {
                            name: "taskFileUrl",
                            label: "Upload a file to AI extractor",
                            alwaysShowLabel: true,
                            fileType: "Extract",
                            subNote: "Supported format: pdf, jpeg and jpg",
                            type: "upload",
                            disabled: isDoing("ai"),
                            onChange: function (newRecord) {
                                clearAllError();
                                var fileName = getAIExtractorFileName("task", newRecord);
                                delete newRecord.taskJobId;
                                delete newRecord.taskResult;
                                if (fileName) {
                                    return __assign(__assign({}, newRecord), { fileName: fileName });
                                }
                                return newRecord;
                            }
                        }
                    ]
                },
                !isDoing("ai") &&
                    isNonEmptyString(record.taskFileUrl) && {
                    fields: [
                        {
                            name: "ai",
                            colStyle: {
                                alignItems: "flex-end",
                                flex: "none"
                            },
                            content: (React.createElement("div", { className: "flex flex-row" },
                                React.createElement(Button, { id: "ai-submit-button", wrapperStyle: { marginLeft: 0 }, onClick: onClickSubmitButton, wrapperClassName: "w-32 bg-sky-400 hover:bg-sky-500 justify-center", text: "Submit to AI", textColor: COLORS.WHITE }))),
                            type: "custom"
                        }
                    ]
                },
                isError("ai") && {
                    fields: [
                        {
                            name: "aiFailed",
                            type: "alert-error",
                            line: "Sorry, we failed to process the uploaded file. Please try again later."
                        }
                    ]
                },
                isDoing("ai") && {
                    fields: [
                        {
                            name: "aiDoing",
                            content: (React.createElement("div", { className: "w-full flex flex-row" },
                                React.createElement(SVG, { src: "/icons/platform/loading.svg", className: "spinner", style: { width: 22, height: 22 }, color: COLORS.SKY["600"] }),
                                React.createElement("span", { className: "pl-2 text-sky-600" }, "Processing the file ..."))),
                            type: "custom"
                        }
                    ]
                },
                record.taskResult && {
                    fields: [
                        {
                            name: "taskResultForFieldsHTML",
                            type: "html",
                            value: "<pre><code class=\"language-json\">".concat(JSON.stringify(record.taskResult, null, 4), "</code></pre>"),
                            disabled: true,
                            useFieldValue: true
                        }
                    ]
                }
            ];
        };
        return {
            id: "general",
            tooltip: "General Form",
            iconSrc: "/icons/platform/form.svg",
            getRows: getRows,
            version: version,
            disabled: disabled == true
        };
    };
    return (React.createElement(FormWrapper, __assign({}, props, { tabs: [getGeneralForm], entity: entity, record: record, hideSaveButton: true, hideActionButton: true, hideTabs: hideTabs, onGoBack: onGoBack })));
};
//# sourceMappingURL=ai-extractor-for-user.js.map