//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useState } from "react";
import { isNonEmptyString, isEmail } from "primeobjects-helper-util/build/cjs/core";
import { callApiBase, getApiEndpoint } from "../util";
import { getRecaptchaToken, Recaptcha } from "primeobjects-ui-web-basic/build/cjs/controls/recaptcha";
import { isFunction, isNil } from "lodash";
import { getSolution, usePrimaryColorName } from "primeobjects-helper-ui";
export var SiteSubmitEmailSection = function (props) {
    var _a, _b;
    var recaptchaId = props.recaptchaId, emailTemplate = props.emailTemplate, hideRecaptcha = props.hideRecaptcha, signUp = props.signUp;
    var solution = props.solution ? props.solution : getSolution();
    var wrapperClassName = isNonEmptyString(props.wrapperClassName)
        ? props.wrapperClassName
        : "";
    var primaryColorName = usePrimaryColorName(solution);
    var colorName = props.colorName ? props.colorName : primaryColorName;
    var apiEndpoint = props.apiEndpoint
        ? props.apiEndpoint
        : getApiEndpoint(solution, "subscription", "subscribe");
    // const apiEndpoint = "http://localhost:3000/prod/subscribe";
    var _c = useState(""), email = _c[0], setEmail = _c[1];
    var _d = useState(""), error = _d[0], setError = _d[1];
    var _e = useState(""), success = _e[0], setSuccess = _e[1];
    var _f = useState(""), doing = _f[0], setDoing = _f[1];
    var _g = useState(false), showRecaptcha = _g[0], setShowRecaptcha = _g[1];
    var contactEmail = props.contactEmail && isNonEmptyString(props.contactEmail)
        ? props.contactEmail
        : "sky";
    var thankYouMessage = props.thankYouMessage && isNonEmptyString(props.thankYouMessage)
        ? props.thankYouMessage
        : "Thank you, you email has been submitted successfully.";
    var errorMessage = props.errorMessage && isNonEmptyString(props.errorMessage)
        ? props.errorMessage
        : "Sorry, we can not submit your request at the moment, please try again later".concat(contactEmail.length > 0 ? " or email to ".concat(contactEmail) : "", ".");
    var buttonText = props.buttonText && isNonEmptyString(props.buttonText)
        ? props.buttonText
        : "Submit";
    var privacyPolicyUrl = (_b = (_a = props.privacyPolicyUrl) !== null && _a !== void 0 ? _a : solution.privacyPolicyUrl) !== null && _b !== void 0 ? _b : "/read/privacy-policy";
    var apiData = props.apiData ? props.apiData : {};
    var recaptchaSiteKey = hideRecaptcha
        ? ""
        : props.recaptchaSiteKey
            ? props.recaptchaSiteKey
            : solution.keys.recaptchaSiteKey;
    if (!apiData.regardingId)
        apiData.regardingId = recaptchaId;
    if (!apiData.emailTemplate)
        apiData.emailTemplate = emailTemplate;
    if (!isNil(apiData.signUp))
        apiData.signUp = signUp;
    useEffect(function () {
        if (!isNonEmptyString(apiEndpoint)) {
            setError("Please provide apiEndpoint!");
        }
    }, [apiEndpoint]);
    var onChangeEmail = function (e) {
        var text = e.target.value;
        if (isEmail(text) && !showRecaptcha) {
            setSuccess("");
            setShowRecaptcha(true);
        }
        setEmail(text);
    };
    var onSubmit = function () {
        if (!isEmail(email)) {
            setError("Please provide a valid email address.");
            return;
        }
        if (props.onSubmit)
            return props.onSubmit(email);
        var recaptchaToken = getRecaptchaToken(recaptchaId);
        if (!isNonEmptyString(recaptchaToken)) {
            setError("Are you a robot? Please finish reCAPTCHA check.");
            return;
        }
        setDoing("Submitting ...");
        setError("");
        callApiBase(apiEndpoint, __assign(__assign({}, apiData), { email: email, recaptchaToken: recaptchaToken }), "POST", {
            solutionId: solution.id
        })
            .then(function (result) {
            setShowRecaptcha(false);
            setEmail("");
            setSuccess(thankYouMessage);
            if (isFunction(props.onSuccess))
                props.onSuccess(result);
        })
            .catch(function (error) {
            setError(errorMessage);
            if (isFunction(props.onError))
                props.onError(error);
        })
            .finally(function () {
            setDoing("");
        });
    };
    var onClickRecaptcha = function () {
        setError("");
    };
    return (React.createElement("div", { className: "".concat(wrapperClassName) },
        showRecaptcha && isNonEmptyString(recaptchaSiteKey) && (React.createElement("div", { className: "w-full flex my-2", onClick: onClickRecaptcha },
            React.createElement(Recaptcha, { id: recaptchaId, siteKey: recaptchaSiteKey }))),
        isNonEmptyString(apiEndpoint) && (React.createElement("div", { className: "mt-3 w-full flex flex-col sm:flex-row", style: { maxWidth: 500 } },
            React.createElement("div", { className: "min-w-0 flex-1" },
                React.createElement("div", { className: "w-full", style: { minWidth: 302 } },
                    React.createElement("input", { onChange: onChangeEmail, value: email, type: "email", className: "block w-full border border-gray-300 rounded-md p-3 text-base text-gray-900 placeholder-gray-500 shadow-sm focus:border-".concat(colorName, "-500 focus:ring-").concat(colorName, "-500"), placeholder: "Enter your email" }))),
            React.createElement("div", { className: "mt-2 ml-0 sm:mt-0 sm:ml-3" },
                React.createElement("button", { disabled: isNonEmptyString(doing), onClick: onSubmit, type: "submit", className: "block w-full h-full rounded-md ".concat(isNonEmptyString(doing)
                        ? "cursor-not-allowed"
                        : "cursor-pointer", " border border-transparent px-5 py-2 bg-").concat(colorName, "-600 text-lg font-medium text-white shadow hover:bg-").concat(colorName, "-700 focus:outline-none focus:ring-2 focus:ring-").concat(colorName, "-700 focus:ring-offset-2 sm:px-10") }, isNonEmptyString(doing) ? doing : buttonText)))),
        isNonEmptyString(error) && (React.createElement("div", { className: "mt-4 w-full flex text-red-700", style: { maxWidth: 460 } }, error)),
        isNonEmptyString(success) && (React.createElement("div", { className: "mt-4 w-full flex text-green-700", style: { maxWidth: 460 } }, success)),
        React.createElement("div", { className: "mt-6" },
            React.createElement("p", { className: "mt-3 text-sm text-gray-600" },
                "We care about the protection of your data. Read our ",
                React.createElement("a", { target: "_blank", href: privacyPolicyUrl, className: "font-medium underline" }, "Privacy Policy"),
                "."))));
};
export default SiteSubmitEmailSection;
//# sourceMappingURL=site-submit-email.js.map